(v0.1.0)=
### 0.1.0 {small}`2017-05-17`

Scanpy computationally outperforms and allows reproducing both the [Cell Ranger
R kit's](https://github.com/scverse/scanpy_usage/tree/master/170503_zheng17)
and most of [Seurat’s](https://github.com/scverse/scanpy_usage/tree/master/170505_seurat)
clustering workflows. {smaller}`A Wolf, P Angerer`
